﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Newtonsoft.Json.Linq;
using System.Web;
using System.Net;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using System.Xml.Linq;

namespace WeatherForecast
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        public class Condition
        {
            public string temp { get; set; }
            public string text { get; set; }
        }

        public class Forecast
        {
            public string high { get; set; }
            public string low { get; set; }
            public string text { get; set; }
        }

        public class Item
        {
            public Condition condition { get; set; }
            public string description { get; set; }
            public List<Forecast> forecast { get; set; }
        }

        public class Atmosphere
        {
            public string humidity { get; set; }
        }

        public class Channel
        {
            public Item item { get; set; }
            public Atmosphere atmosphere { get; set; }
        }

        public class Results
        {
            public Channel channel { get; set; }
        }

        public class Query
        {
            public Results results { get; set; }
        }

        public class RootObject
        {
            public Query query { get; set; }
        }

        public class Convert
        {
            public static int FahrenheitToCelsius(double f)
            {
                return (int)((5.0 / 9.0) * (f - 32));
            }

            public static string ConditionTextToPersian(string s)
            {
                string p = "";
                switch (s)
                {
                    case "tornado":
                        p = "گردباد";
                        break;
                    case "tropical storm":
                        p = "طوفان گرمسیری";
                        break;
                    case "hurricane":
                        p = "طوفان";
                        break;
                    case "severe thunderstorms":
                        p = "رعد و برق شدید";
                        break;
                    case "thunderstorms":
                        p = "رعد و برق";
                        break;
                    case "mixed rain and snow":
                        p = "مخلوط باران و برف";
                        break;
                    case "mixed rain and sleet":
                        p = "مخلوط باران و بوران";
                        break;
                    case "mixed snow and sleet":
                        p = "مخلوط برف و بوران";
                        break;
                    case "freezing drizzle":
                        p = "نم نم باران منجماد";
                        break;
                    case "drizzle":
                        p = "نم نم باران";
                        break;
                    case "freezing rain":
                        p = "باران منجماد";
                        break;
                    case "showers":
                        p = "رگبار";
                        break;
                    case "snow flurries":
                        p = "وزش ناگهانی باد برف";
                        break;
                    case "light snow showers":
                        p = "بارش برف سبک";
                        break;
                    case "blowing snow":
                        p = "بارش برف";
                        break;
                    case "snow":
                        p = "برف";
                        break;
                    case "hail":
                        p = "تگرگ";
                        break;
                    case "sleet":
                        p = "بوران";
                        break;
                    case "dust":
                        p = "گرد و خاک";
                        break;
                    case "foggy":
                        p = "مه آلود";
                        break;
                    case "haze":
                        p = "مه";
                        break;
                    case "smoky":
                        p = "دودی";
                        break;
                    case "blustery":
                        p = "باد";
                        break;
                    case "windy":
                        p = "پر باد";
                        break;
                    case "cold":
                        p = "سرد";
                        break;
                    case "cloudy":
                        p = "ابری";
                        break;
                    case "mostly cloudy":
                        p = "تمام ابری";
                        break;
                    case "clear":
                        p = "صاف";
                        break;
                    case "sunny":
                        p = "آفتابی";
                        break;
                    case "fair":
                        p = "نسبتا خوب";
                        break;
                    case "mixed rain and hail":
                        p = "مخلوط باران و تگرگ";
                        break;
                    case "hot":
                        p = "گرم";
                        break;
                    case "isolated thunderstorms":
                        p = "رعد و برق";
                        break;
                    case "scattered thunderstorms":
                        p = "رعد و برق پراکنده";
                        break;
                    case "scattered showers":
                        p = "رگبار پراکنده";
                        break;
                    case "heavy snow":
                        p = "برف سنگین";
                        break;
                    case "scattered snow showers":
                        p = "بارش برف پراکنده";
                        break;
                    case "partly cloudy":
                        p = "نسبتا خوب";
                        break;
                    case "thundershowers":
                        p = "رعد و برق";
                        break;
                    case "snow showers":
                        p = "بارش برف";
                        break;
                    case "showers late":
                        p = "بارش آخروقت";
                        break;
                    case "widespread dust":
                        p = "گرد و غبار گسترده";
                        break;
                    case "mostly sunny":
                        p = "تا حدی آفتابی";
                        break;
                    default:
                        p = "نامشخص";
                        break;
                }              
                return p;
            }
        }

        public class Weather
        {
            public static RootObject GetData(string city)
            {
                string query = "select * from weather.forecast where woeid in (select woeid from geo.placefinder where text='" + city + "')";
                StringBuilder theWebAddress = new StringBuilder();
                theWebAddress.Append("http://query.yahooapis.com/v1/public/yql?");
                theWebAddress.Append("q=" + HttpUtility.UrlEncode(query));
                theWebAddress.Append("&format=json");
                theWebAddress.Append("&diagnostics=false");
                string results = "";
                using (WebClient wc = new WebClient())
                {
                    wc.Encoding = Encoding.UTF8;
                    results = wc.DownloadString(theWebAddress.ToString());
                }
                return JsonConvert.DeserializeObject<RootObject>(results);
            }
        }
          
        private void MainForm_Load(object sender, EventArgs e)
        {
            XElement cityData = XElement.Load("Cities.xml");
            cboCityName.DataSource = cityData.Descendants("CityName").Select(c => c.Element("Persian").Value).ToList();

            RootObject obj = Weather.GetData(cityData.Descendants("CityName").Where(s => s.Element("Persian").Value == cboCityName.Text).Select(s => s.Element("English").Value).First().ToString());
            lblCurrentConditions.Text = Convert.ConditionTextToPersian(obj.query.results.channel.item.condition.text.ToLower());
            lblCurrentTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.condition.temp)).ToString();
            lblHighTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[0].high)).ToString();
            lblLowTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[0].low)).ToString();
            lblHumidity.Text = obj.query.results.channel.atmosphere.humidity + "%";
            pictureBoxWeatherForecast.Load(Regex.Match(obj.query.results.channel.item.description, "<img.+?src=[\"'](.+?)[\"'].+?>", RegexOptions.IgnoreCase).Groups[1].Value);

            lblToday.Text = Convert.ConditionTextToPersian(obj.query.results.channel.item.forecast[0].text.ToLower());
            lblTodayTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[0].high)).ToString();

            lblTomorrow.Text = Convert.ConditionTextToPersian(obj.query.results.channel.item.forecast[1].text.ToLower());
            lblTomorrowTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[1].high)).ToString();
        }

        private void btnShow_Click(object sender, EventArgs e)
        {
            XElement cityData = XElement.Load("Cities.xml");

            RootObject obj = Weather.GetData(cityData.Descendants("CityName").Where(s => s.Element("Persian").Value == cboCityName.Text).Select(s => s.Element("English").Value).First().ToString());
            lblCurrentConditions.Text = Convert.ConditionTextToPersian(obj.query.results.channel.item.condition.text.ToLower());
            lblCurrentTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.condition.temp)).ToString();
            lblHighTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[0].high)).ToString();
            lblLowTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[0].low)).ToString();
            lblHumidity.Text = obj.query.results.channel.atmosphere.humidity + "%";
            pictureBoxWeatherForecast.Load(Regex.Match(obj.query.results.channel.item.description, "<img.+?src=[\"'](.+?)[\"'].+?>", RegexOptions.IgnoreCase).Groups[1].Value);

            lblToday.Text = Convert.ConditionTextToPersian(obj.query.results.channel.item.forecast[0].text.ToLower());
            lblTodayTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[0].high)).ToString();

            lblTomorrow.Text = Convert.ConditionTextToPersian(obj.query.results.channel.item.forecast[1].text.ToLower());
            lblTomorrowTemp.Text = Convert.FahrenheitToCelsius(double.Parse(obj.query.results.channel.item.forecast[1].high)).ToString();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            System.Diagnostics.Process.Start("http://WWw.SourceCodes.ir");

        }

      

    }
}
